<?php

namespace Litecms\ContractSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\ContractSetting\Models\ContractSetting;

class ContractSettingPolicy
{

    /**
     * Determine if the given user can view the contract_setting.
     *
     * @param UserPolicy $user
     * @param ContractSetting $contract_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, ContractSetting $contract_setting)
    {
        if ($user->canDo('contract_setting.contract_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $contract_setting->user_id == user_id() && $contract_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a contract_setting.
     *
     * @param UserPolicy $user
     * @param ContractSetting $contract_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('contract_setting.contract_setting.create');
    }

    /**
     * Determine if the given user can update the given contract_setting.
     *
     * @param UserPolicy $user
     * @param ContractSetting $contract_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, ContractSetting $contract_setting)
    {
        if ($user->canDo('contract_setting.contract_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $contract_setting->user_id == user_id() && $contract_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given contract_setting.
     *
     * @param UserPolicy $user
     * @param ContractSetting $contract_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ContractSetting $contract_setting)
    {
        return $contract_setting->user_id == user_id() && $contract_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given contract_setting.
     *
     * @param UserPolicy $user
     * @param ContractSetting $contract_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ContractSetting $contract_setting)
    {
        if ($user->canDo('contract_setting.contract_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given contract_setting.
     *
     * @param UserPolicy $user
     * @param ContractSetting $contract_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ContractSetting $contract_setting)
    {
        if ($user->canDo('contract_setting.contract_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
