<?php

namespace Litecms\ContractSetting\Providers;

use Illuminate\Support\ServiceProvider;

class ContractSettingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'contract_setting');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'contract_setting');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.contract_setting', function ($app) {
            return $this->app->make('Litecms\ContractSetting\ContractSetting');
        });

                // Bind ContractSetting to repository
        $this->app->bind(
            'Litecms\ContractSetting\Interfaces\ContractSettingRepositoryInterface',
            \Litecms\ContractSetting\Repositories\Eloquent\ContractSettingRepository::class
        );

        $this->app->register(\Litecms\ContractSetting\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\ContractSetting\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\ContractSetting\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.contract_setting'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/contract_setting.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/contract_setting')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/contract_setting')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
